title = 'pyredq'
description = 'Light and fast ordered message queue for Python3 using Redis'
url = 'https://github.com/adrianchifor/pyredq'
version = '0.3.0'
author = 'Adrian Chifor'
author_email = 'me@adrianchifor.com'
license = 'Apache License 2.0'
